@@ -16,16 +16,27 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.batch_v1alpha import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
@@ -33,20 +44,22 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.batch_v1alpha.services.batch_service import pagers
-from google.cloud.batch_v1alpha.types import batch
-from google.cloud.batch_v1alpha.types import job
-from google.cloud.batch_v1alpha.types import job as gcb_job
-from google.cloud.batch_v1alpha.types import task
 from google.cloud.location import locations_pb2  # type: ignore
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.longrunning import operations_pb2
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import BatchServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import BatchServiceGrpcAsyncIOTransport
+
+from google.cloud.batch_v1alpha.services.batch_service import pagers
+from google.cloud.batch_v1alpha.types import batch
+from google.cloud.batch_v1alpha.types import job
+from google.cloud.batch_v1alpha.types import job as gcb_job
+from google.cloud.batch_v1alpha.types import task
+
 from .client import BatchServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, BatchServiceTransport
+from .transports.grpc_asyncio import BatchServiceGrpcAsyncIOTransport
 
 
 class BatchServiceAsyncClient:
@@ -172,9 +185,9 @@ class BatchServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, BatchServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the batch service client.
@@ -218,13 +231,13 @@ class BatchServiceAsyncClient:
 
     async def create_job(
         self,
-        request: Union[batch.CreateJobRequest, dict] = None,
+        request: Optional[Union[batch.CreateJobRequest, dict]] = None,
         *,
-        parent: str = None,
-        job: gcb_job.Job = None,
-        job_id: str = None,
+        parent: Optional[str] = None,
+        job: Optional[gcb_job.Job] = None,
+        job_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcb_job.Job:
         r"""Create a Job.
@@ -256,7 +269,7 @@ class BatchServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.batch_v1alpha.types.CreateJobRequest, dict]):
+            request (Optional[Union[google.cloud.batch_v1alpha.types.CreateJobRequest, dict]]):
                 The request object. CreateJob Request.
             parent (:class:`str`):
                 Required. The parent resource name
@@ -273,11 +286,11 @@ class BatchServiceAsyncClient:
                 should not be set.
             job_id (:class:`str`):
                 ID used to uniquely identify the Job within its parent
-                scope. This field should contain at most 63 characters.
-                Only alphanumeric characters or '-' are accepted. The
-                '-' character cannot be the first or the last one. A
-                system generated ID will be used if the field is not
-                set.
+                scope. This field should contain at most 63 characters
+                and must start with lowercase characters. Only lowercase
+                characters, numbers and '-' are accepted. The '-'
+                character cannot be the first or the last one. A system
+                generated ID will be used if the field is not set.
 
                 The job.name field in the request will be ignored and
                 the created resource name of the Job will be
@@ -344,11 +357,11 @@ class BatchServiceAsyncClient:
 
     async def get_job(
         self,
-        request: Union[batch.GetJobRequest, dict] = None,
+        request: Optional[Union[batch.GetJobRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> job.Job:
         r"""Get a Job specified by its resource name.
@@ -380,7 +393,7 @@ class BatchServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.batch_v1alpha.types.GetJobRequest, dict]):
+            request (Optional[Union[google.cloud.batch_v1alpha.types.GetJobRequest, dict]]):
                 The request object. GetJob Request.
             name (:class:`str`):
                 Required. Job name.
@@ -450,11 +463,11 @@ class BatchServiceAsyncClient:
 
     async def delete_job(
         self,
-        request: Union[batch.DeleteJobRequest, dict] = None,
+        request: Optional[Union[batch.DeleteJobRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Delete a Job.
@@ -483,13 +496,13 @@ class BatchServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.batch_v1alpha.types.DeleteJobRequest, dict]):
+            request (Optional[Union[google.cloud.batch_v1alpha.types.DeleteJobRequest, dict]]):
                 The request object. DeleteJob Request.
             name (:class:`str`):
                 Job name.
@@ -570,11 +583,11 @@ class BatchServiceAsyncClient:
 
     async def list_jobs(
         self,
-        request: Union[batch.ListJobsRequest, dict] = None,
+        request: Optional[Union[batch.ListJobsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListJobsAsyncPager:
         r"""List all Jobs for a project within a region.
@@ -606,7 +619,7 @@ class BatchServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.batch_v1alpha.types.ListJobsRequest, dict]):
+            request (Optional[Union[google.cloud.batch_v1alpha.types.ListJobsRequest, dict]]):
                 The request object. ListJob Request.
             parent (:class:`str`):
                 Parent path.
@@ -689,11 +702,11 @@ class BatchServiceAsyncClient:
 
     async def get_task(
         self,
-        request: Union[batch.GetTaskRequest, dict] = None,
+        request: Optional[Union[batch.GetTaskRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> task.Task:
         r"""Return a single Task.
@@ -725,7 +738,7 @@ class BatchServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.batch_v1alpha.types.GetTaskRequest, dict]):
+            request (Optional[Union[google.cloud.batch_v1alpha.types.GetTaskRequest, dict]]):
                 The request object. Request for a single Task by name.
             name (:class:`str`):
                 Required. Task name.
@@ -795,11 +808,11 @@ class BatchServiceAsyncClient:
 
     async def list_tasks(
         self,
-        request: Union[batch.ListTasksRequest, dict] = None,
+        request: Optional[Union[batch.ListTasksRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTasksAsyncPager:
         r"""List Tasks associated with a job.
@@ -832,7 +845,7 @@ class BatchServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.batch_v1alpha.types.ListTasksRequest, dict]):
+            request (Optional[Union[google.cloud.batch_v1alpha.types.ListTasksRequest, dict]]):
                 The request object. ListTasks Request.
             parent (:class:`str`):
                 Required. Name of a TaskGroup from which Tasks are being
@@ -918,10 +931,10 @@ class BatchServiceAsyncClient:
 
     async def list_operations(
         self,
-        request: operations_pb2.ListOperationsRequest = None,
+        request: Optional[operations_pb2.ListOperationsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.ListOperationsResponse:
         r"""Lists operations that match the specified filter in the request.
@@ -972,10 +985,10 @@ class BatchServiceAsyncClient:
 
     async def get_operation(
         self,
-        request: operations_pb2.GetOperationRequest = None,
+        request: Optional[operations_pb2.GetOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.Operation:
         r"""Gets the latest state of a long-running operation.
@@ -1026,10 +1039,10 @@ class BatchServiceAsyncClient:
 
     async def delete_operation(
         self,
-        request: operations_pb2.DeleteOperationRequest = None,
+        request: Optional[operations_pb2.DeleteOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a long-running operation.
@@ -1081,10 +1094,10 @@ class BatchServiceAsyncClient:
 
     async def cancel_operation(
         self,
-        request: operations_pb2.CancelOperationRequest = None,
+        request: Optional[operations_pb2.CancelOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Starts asynchronous cancellation on a long-running operation.
@@ -1135,10 +1148,10 @@ class BatchServiceAsyncClient:
 
     async def set_iam_policy(
         self,
-        request: iam_policy_pb2.SetIamPolicyRequest = None,
+        request: Optional[iam_policy_pb2.SetIamPolicyRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Sets the IAM access control policy on the specified function.
@@ -1255,10 +1268,10 @@ class BatchServiceAsyncClient:
 
     async def get_iam_policy(
         self,
-        request: iam_policy_pb2.GetIamPolicyRequest = None,
+        request: Optional[iam_policy_pb2.GetIamPolicyRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Gets the IAM access control policy for a function.
@@ -1376,10 +1389,10 @@ class BatchServiceAsyncClient:
 
     async def test_iam_permissions(
         self,
-        request: iam_policy_pb2.TestIamPermissionsRequest = None,
+        request: Optional[iam_policy_pb2.TestIamPermissionsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> iam_policy_pb2.TestIamPermissionsResponse:
         r"""Tests the specified IAM permissions against the IAM access control
@@ -1435,10 +1448,10 @@ class BatchServiceAsyncClient:
 
     async def get_location(
         self,
-        request: locations_pb2.GetLocationRequest = None,
+        request: Optional[locations_pb2.GetLocationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> locations_pb2.Location:
         r"""Gets information about a location.
@@ -1489,10 +1502,10 @@ class BatchServiceAsyncClient:
 
     async def list_locations(
         self,
-        request: locations_pb2.ListLocationsRequest = None,
+        request: Optional[locations_pb2.ListLocationsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> locations_pb2.ListLocationsResponse:
         r"""Lists information about the supported locations for this service.
@@ -1548,14 +1561,9 @@ class BatchServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-batch",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("BatchServiceAsyncClient",)
